
## <p style="text-align:center;"> A package of tools and files from the Golding lab @ UT Austin for compartmental modeling, using the simulation software, NEURON. </p>
## [<p style="text-align:center;">Github</p>](https://github.com/jaredcasarez/golding-NEURON)
## [<p style="text-align:center;">Golding lab</p>](https://goldinglab.org) 
## [<p style="text-align:center;">NEURON</p>](https://www.neuron.yale.edu/neuron/) 